@@ -1,5 +1,6 @@
 from .scraper import Scraper, TAG_LINK, HTMLSession
 from .url import URL
+from .proxy import ProxyManager, PROXY
 from .logging import LogConfig, LOG_LEVEL
 from .versions import __VERSION__
 
@@ -8,6 +9,8 @@ __all__ = [
     "TAG_LINK",
     "HTMLSession",
     "URL",
+    "ProxyManager",
+    "PROXY",
     "LogConfig",
     "LOG_LEVEL",
     "__VERSION__",
